Type: Package
Package: maSAE
Title: Mandallaz' Model-Assisted Small Area Estimators
Version: 2.0.3
Authors@R: 
    c(person(given = "Andreas Dominik",
             family = "Cullmann",
             role = c("aut", "cre"),
             email = "fvafrcu@mailbox.org"),
      person(given = "Daniel",
             family = "Mandallaz",
             role = "ctb"),
      person(given = c("Alexander", "Francis"),
             family = "Massey",
             role = "ctb"))
Description: An S4 implementation of the unbiased extension of
    the model- assisted synthetic-regression estimator proposed by
    Mandallaz (2013) <DOI:10.1139/cjfr-2012-0381>, Mandallaz et al. (2013)
    <DOI:10.1139/cjfr-2013-0181> and Mandallaz (2014)
    <DOI:10.1139/cjfr-2013-0449>.  It yields smaller variances than the
    standard bias correction, the generalised regression estimator.
License: BSD_2_clause + file LICENSE
URL: https://gitlab.com/fvafrCU/maSAE
Depends: R (>= 3.6.0)
Imports: methods, stats
Suggests: devtools, forestinventory, JoSAE, knitr, microbenchmark,
        nlme, pkgload, rmarkdown, rprojroot, rsae, RUnit, R.rsp, sae,
        testthat
VignetteBuilder: utils, knitr, R.rsp
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2021-04-12 09:20:38 UTC; qwer
Author: Andreas Dominik Cullmann [aut, cre],
  Daniel Mandallaz [ctb],
  Alexander Francis Massey [ctb]
Maintainer: Andreas Dominik Cullmann <fvafrcu@mailbox.org>
Repository: CRAN
Date/Publication: 2021-04-12 09:40:02 UTC
Built: R 4.6.0; ; 2026-04-25 20:12:17 UTC; unix
